@@ -44,7 +44,9 @@
   #include "config.h"
 #endif
 
+#include <X11/Xlib.h>
 #include <X11/extensions/XvMC.h>
+#include <X11/extensions/XvMClib.h>
 #include <X11/extensions/vldXvMC.h>
 #include <dlfcn.h>
 #include <stdio.h>
